==> members-facade-2.1.1-20201105.054641-4-sources.jar: com/bizvane/members/facade/constants/WxFriendsAdvancedSearchConstant.java <==
package com.bizvane.members.facade.constants;

public class WxFriendsAdvancedSearchConstant {
	// 品牌id
	public static final String BRAND_ID = "brandId";
	// 公司id
	public static final String SYS_COMPANY_ID = "sysCompanyId";
	// 外联表id
	public static final String EXTERNAL_ID = "externalId";
	// 导购id
	public static final String GUIDE_ID = "guideId";
	// 联系人备注
	public static final String FRIENDS_COMMENT = "friendsComment";
	// 外联userId
	public static final String EXTERNAL_USER_ID = "externalUserId";
	// 外联类型 1微信 2企业微信
	public static final String EXTERNAL_TYPE = "externalType";
	// unionId
	public static final String UNION_ID = "unionId";
	// 外部联系人名称
	public static final String EXTERNAL_NAME = "externalName";
	// 头像
	public static final String HEAD_PORTRAITS = "headPortraits";
	// 性别
	public static final String GENDER = "gender";
	// 会员code
	public static final String MEMBER_CODE = "memberCode";
	// 等级id
	public static final String LEVEL_ID = "levelId";
	// 服务店铺id
	public static final String SERVICE_STORE_ID = "serviceStoreId";
	// 服务导购id
	public static final String SERVICE_GUIDE_ID = "serviceGuideId";
	// 粉丝是否关注 2已关注 1未关注(null未关注)
	public static final String FOCUS = "focus";
	// 会员手机号码
	public static final String PHONE = "phone";
	// 会员姓名
	public static final String MEMBER_NAME = "memberName";

	public static final String CREATE_DATE = "createDate";

	public static final String ES_MBR_FRIENDS_ID = "esMbrFriendsId";

	public static final String FRIEND_STATUS ="friendStatus";

	public static final String store = "store";

	public static final String storeId="storeId";

}

==> members-facade-20250718111-20250721.155731-1-sources.jar: com/bizvane/members/facade/constants/WxFriendsAdvancedSearchConstant.java <==
package com.bizvane.members.facade.constants;

public class WxFriendsAdvancedSearchConstant {
	// 品牌id
	public static final String BRAND_ID = "brandId";
	// 公司id
	public static final String SYS_COMPANY_ID = "sysCompanyId";
	// 外联表id
	public static final String EXTERNAL_ID = "externalId";
	// 导购id
	public static final String GUIDE_ID = "guideId";
	// 联系人备注
	public static final String FRIENDS_COMMENT = "friendsComment";
	// 外联userId
	public static final String EXTERNAL_USER_ID = "externalUserId";
	// 外联类型 1微信 2企业微信
	public static final String EXTERNAL_TYPE = "externalType";
	// unionId
	public static final String UNION_ID = "unionId.keyword";
	// 外部联系人名称
	public static final String EXTERNAL_NAME = "externalName";
	// 头像
	public static final String HEAD_PORTRAITS = "headPortraits";
	// 性别
	public static final String GENDER = "gender";
	// 会员code
	public static final String MEMBER_CODE = "memberCode";
	// 等级id
	public static final String LEVEL_ID = "levelId";
	// 服务店铺id
	public static final String SERVICE_STORE_ID = "serviceStoreId";
	// 服务导购id
	public static final String SERVICE_GUIDE_ID = "serviceGuideId";
	// 粉丝是否关注 2已关注 1未关注(null未关注)
	public static final String FOCUS = "focus";
	// 是否专属好友关系
	public static final String EXCLUSIVE_FRIEND = "exclusiveFriend";
	// 会员手机号码
	public static final String PHONE = "phone";
	// 会员姓名
	public static final String MEMBER_NAME = "memberName";

	public static final String CREATE_DATE = "createDate";

	public static final String ES_MBR_FRIENDS_ID = "esMbrFriendsId";

	public static final String FRIEND_STATUS ="friendStatus";

	public static final String store = "store";

	public static final String storeId="storeId";

}
